Group of rules related to DAX performance.



# DAX-006: Literals in CALCULATE

**Applies to:**

- [Measure](/SSAS/entities/measure)

**Fix State:** Not Automatically Fixable

```

CALCULATE expressions should not contain number/string literals.
This helps maintain clarity and performance in DAX expressions.

```
